@@ -2,10 +2,10 @@
 
 #
 # DaVinci Resolve Multi Debian package creator
-# Release 2022-12-05
+# Release 2024-04-12
 # By Daniel Tufvesson
 #
-MAKERESOLVEDEB_VERSION=1.6.4
+MAKERESOLVEDEB_VERSION=1.7.0
 
 check_command() {
     echo -n "Checking for ${1}..."
@@ -357,6 +357,60 @@ chmod -R a+rw /var/BlackmagicDesign/"DaVinci Resolve"
 EOF
 }
 
+process_19() {
+    # Create directories
+    create_directory ${RESOLVE_BASE_DIR}/easyDCP
+    create_directory ${RESOLVE_BASE_DIR}/scripts
+    create_directory ${RESOLVE_BASE_DIR}/.license
+    create_directory ${RESOLVE_BASE_DIR}/share
+    create_directory ${RESOLVE_BASE_DIR}/Fairlight
+
+    # Copy objects
+    copy_object ${UNPACK_DIR}/bin ${RESOLVE_BASE_DIR}
+    copy_object ${UNPACK_DIR}/Control ${RESOLVE_BASE_DIR}
+    copy_object ${UNPACK_DIR}/Certificates ${RESOLVE_BASE_DIR}
+    copy_object ${UNPACK_DIR}/DaVinci\ Control\ Panels\ Setup ${RESOLVE_BASE_DIR}
+    copy_object ${UNPACK_DIR}/Developer ${RESOLVE_BASE_DIR}
+    copy_object ${UNPACK_DIR}/docs ${RESOLVE_BASE_DIR}
+    copy_object ${UNPACK_DIR}/Fairlight\ Studio\ Utility ${RESOLVE_BASE_DIR}
+    copy_object ${UNPACK_DIR}/Fusion ${RESOLVE_BASE_DIR}
+    copy_object ${UNPACK_DIR}/graphics ${RESOLVE_BASE_DIR}
+    copy_object ${UNPACK_DIR}/libs ${RESOLVE_BASE_DIR}
+    copy_object ${UNPACK_DIR}/LUT ${RESOLVE_BASE_DIR}
+    if [[ -z "$SKIP_ONBOARDING" ]]; then
+	copy_object ${UNPACK_DIR}/Onboarding ${RESOLVE_BASE_DIR}
+    fi
+    copy_object ${UNPACK_DIR}/plugins ${RESOLVE_BASE_DIR}
+    copy_object ${UNPACK_DIR}/Technical\ Documentation ${RESOLVE_BASE_DIR}
+    copy_object ${UNPACK_DIR}/UI_Resource ${RESOLVE_BASE_DIR}
+    copy_object ${UNPACK_DIR}/scripts/script.checkfirmware ${RESOLVE_BASE_DIR}/scripts/
+    copy_object ${UNPACK_DIR}/scripts/script.getlogs.v4 ${RESOLVE_BASE_DIR}/scripts/
+    copy_object ${UNPACK_DIR}/scripts/script.start ${RESOLVE_BASE_DIR}/scripts/
+    copy_object ${UNPACK_DIR}/share/default-config.dat ${RESOLVE_BASE_DIR}/share/
+    copy_object ${UNPACK_DIR}/share/default_cm_config.bin ${RESOLVE_BASE_DIR}/share/
+    copy_object ${UNPACK_DIR}/share/log-conf.xml ${RESOLVE_BASE_DIR}/share/
+    if [[ -e ${UNPACK_DIR}/share/remote-monitoring-log-conf.xml ]]; then
+	copy_object ${UNPACK_DIR}/share/remote-monitoring-log-conf.xml ${RESOLVE_BASE_DIR}/share/
+    fi
+    
+    # Extract panel API library
+    create_directory ${DEB_DIR}/usr/lib
+    extract_tgz ${UNPACK_DIR}/share/panels/dvpanel-framework-linux-x86_64.tgz ${DEB_DIR}/usr/lib libDaVinciPanelAPI.so
+    extract_tgz ${UNPACK_DIR}/share/panels/dvpanel-framework-linux-x86_64.tgz ${DEB_DIR}/usr/lib libFairlightPanelAPI.so
+
+    # Create common data dir
+    create_directory ${DEB_DIR}/var/BlackmagicDesign/DaVinci\ Resolve
+
+    # Add postinst commands
+    cat >> ${DEB_DIR}/DEBIAN/postinst <<EOF
+chmod -R a+rw /opt/resolve/easyDCP
+chmod -R a+rw /opt/resolve/LUT
+chmod -R a+rw /opt/resolve/.license
+chmod -R a+rw /opt/resolve/Fairlight
+chmod -R a+rw /var/BlackmagicDesign/"DaVinci Resolve"
+EOF
+}
+
 process_braw() {
     if [[ ! -z "$SKIP_BRAW" ]]; then
 	return;
@@ -677,14 +731,22 @@ case $RESOLVE_VERSION in
 	process_udev
 	process_desktop_shortcuts
 	;;
-    *)
-	echo "Unknown Resolve version"
-	echo "Trying Resolve 18 conversion process"
+    19.*)
+	echo "Using Resolve 19 conversion process"
 	installer_extract_native
-	process_18
+	process_19
 	process_braw
 	process_udev
-	process_desktop_chortcuts
+	process_desktop_shortcuts
+	;;
+    *)
+	echo "Unknown Resolve version"
+	echo "Trying Resolve 19 conversion process"
+	installer_extract_native
+	process_19
+	process_braw
+	process_udev
+	process_desktop_shortcuts
 	;;
 esac
 
